#  SAP LeanIX for Enterprise Architects
### On this page
  * [Access Your Workspace](https://help.sap.com/docs/leanix/ea/for-enterprise-architects#access-your-workspace)
  * [Understand the Meta Model](https://help.sap.com/docs/leanix/ea/for-enterprise-architects#understand-the-meta-model)
  * [Explore Use Cases](https://help.sap.com/docs/leanix/ea/for-enterprise-architects#explore-use-cases)
  * [Import Data into Your Workspace](https://help.sap.com/docs/leanix/ea/for-enterprise-architects#import-data-into-your-workspace)
  * [Collect Data from Fact Sheet Owners](https://help.sap.com/docs/leanix/ea/for-enterprise-architects#collect-data-from-fact-sheet-owners)


First steps in using SAP LeanIX as an enterprise architect.
